@@ -1,15 +1,17 @@
-<?php
-include ("../jpgraph.php");
-include ("../jpgraph_line.php");
+<?php // content="text/plain; charset=utf-8"
+require_once ('jpgraph/jpgraph.php');
+require_once ('jpgraph/jpgraph_line.php');
+require_once ('jpgraph/jpgraph_utils.inc.php');
 
 $f = new FuncGenerator('cos($i)','$i*$i*$i');
 list($xdata,$ydata) = $f->E(-M_PI,M_PI,25);
 
-$graph = new Graph(380,450,"auto");
+$graph = new Graph(380,450);
+$graph->clearTheme();
 $graph->SetScale("linlin");
 $graph->SetShadow();
-$graph->img->SetMargin(50,50,60,40);	
-$graph->SetBox(true,'black',2);	
+$graph->img->SetMargin(50,50,60,40);
+$graph->SetBox(true,'black',2);
 $graph->SetMarginColor('white');
 $graph->SetColor('lightyellow');
 $graph->SetAxisStyle(AXSTYLE_SIMPLE);
@@ -29,5 +31,3 @@ $lp1->SetColor("blue");
 $graph->Add($lp1);
 $graph->Stroke();
 ?>
-
-
